OC.L10N.register(
    "mail",
    {
    "Personal" : "Udmawan",
    "Mail" : "Tirawt",
    "Save" : "Sekles",
    "Name" : "Nom",
    "Password" : "Awal uffir",
    "None" : "Ula d yiwen",
    "Email address" : "Tansa imayl",
    "Cancel" : "Sefsex",
    "Accounts" : "Imiḍanen",
    "General" : "Amatu",
    "About" : "Γef",
    "Delete" : "Kkes",
    "Search" : "Nadi",
    "Send" : "Tuzna",
    "Refresh" : "Sismeḍ",
    "Choose" : "Fren",
    "Confirm" : "Serggeg",
    "Favorite" : "Menyif",
    "Back" : "Retour",
    "Mark as unread" : "Creḍ ur yettwaɣra ara",
    "Mark as read" : "Creḍ yettwaɣra",
    "Create" : "Snulfu-d",
    "Select" : "Fren",
    "Comment" : "Commentaire",
    "Remove" : "Kkes",
    "Today" : "Ass-a",
    "Other" : "Wayeḍ",
    "Forward" : "Avancer",
    "Translate" : "Suqel",
    "Move" : "Senkez",
    "Remove account" : "Kkes amiḍan",
    "Loading …" : "Asali ...",
    "Rename" : "Beddel isem",
    "Reply" : "Err",
    "Retry" : "Ɛreḍ tikkelt-nniḍen",
    "Message" : "Izen",
    "Copy to clipboard" : "Copier dans le presse-papiers",
    "Add" : "Rnu",
    "Close" : "Mdel",
    "Tags" : "Tibzimin",
    "User" : "Aseqdac",
    "Guest" : "Inebgi",
    "Group" : "Agraw",
    "All" : "Akk",
    "Favorites" : "Imenyafen",
    "Inbox" : "Tanaka",
    "Message sent" : "Izen yettwazen"
},
"nplurals=2; plural=(n != 1);");
